# safethread

Python utilities classes for safe deployment and management of Threads, synchronization and Python data structures.

Includes:
- Thread-safe wrapper classes for most Python data structures
- Unit test for each class provided

**Summary**
- [safethread](#safethread)
  - [Run automated tests (unit tests)](#run-automated-tests-unit-tests)
  - [Special thanks / Acknowledgments](#special-thanks--acknowledgments)
  - [License and Copyright](#license-and-copyright)

## Run automated tests (unit tests)

Run the following:

```batch
call .\install_dependencies.bat
call .\run_tests.bat
```

## Special thanks / Acknowledgments

- Python 3

## License and Copyright

Copyright (C) [2025] Andre Luiz Romano Madureira

This project is licensed under the Apache License 2.0.  

For more details, see the full license text (see [./LICENSE](./LICENSE) file).
